﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Diagnostics;

namespace DataLayer.Queries
{
    public class QueryBase
    {
        protected bool success;
        protected string error;
        protected Stopwatch sw;

        public QueryBase()
        {
            this.sw = new Stopwatch();
        }

        public bool Success
        {
            get { return this.success; }
        }

        public string Error
        {
            get { return this.error; }
        }

        public long ElapsedMs
        {
            get { return this.sw.ElapsedMilliseconds; }
        }

        protected virtual bool Execute()
        {
            this.error = string.Format("Execute not implementd in {0}", this.GetType());
            return false;
        }

        public bool RunQuery()
        {
            sw.Start();
            this.error = null;

            try
            {
                this.success = this.Execute();
            }
            catch(Exception e)
            {
                this.error = e.Message;
                this.success = false;
            }
            finally
            {
                this.sw.Stop();
            }

            return this.success;
        }
    }
}
